@@ -54,6 +54,23 @@ class GWLoss(nn.Module):
         return self.nll((self.gaussian(pt, variance=0.1 * math.exp(1), mean=0.5) - 0.1 * pt) * logpt, target)
 
 
+class DiceLoss(nn.Module):
+    """DiceLoss implemented from 'Dice Loss for Data-imbalanced NLP Tasks'
+    Useful in dealing with unbalanced data
+    Add softmax automatically
+    """
+
+    def __init__(self):
+        super(DiceLoss, self).__init__()
+
+    def forward(self, y_pred, y_true):
+        y_pred = torch.softmax(y_pred, dim=1)
+        pred_prob = torch.gather(y_pred, dim=1, index=y_true.unsqueeze(1))
+        dsc_i = 1 - ((1 - pred_prob) * pred_prob) / ((1 - pred_prob) * pred_prob + 1)
+        dice_loss = dsc_i.mean()
+        return dice_loss
+
+
 class FocalLoss(nn.Module):
     def __init__(self, gamma=2):
         super(FocalLoss, self).__init__()
